@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codecommit._jsii
 import aws_cdk.aws_codepipeline._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-merge-action",
-    "1.2.8",
+    "1.2.11",
     __name__[0:-6],
-    "cdk-codepipeline-merge-action@1.2.8.jsii.tgz",
+    "cdk-codepipeline-merge-action@1.2.11.jsii.tgz",
 )
 
 __all__ = [
